import type { IoHelper } from './io-helper';
import type * as make from './message-maker';
import type { Duration } from '../../../payloads/types';
import type { IActionAwareIoHost } from '../io-host';
import type { IoDefaultMessages } from './io-default-messages';
export interface SpanEnd {
    readonly duration: number;
}
/**
 * Describes a specific span
 *
 * A span definition is a pair of `IoMessageMaker`s to create a start and end message of the span respectively.
 * It also has a display name, that is used for auto-generated message text when they are not provided.
 */
export interface SpanDefinition<S extends object, E extends SpanEnd> {
    readonly name: string;
    readonly start: make.IoMessageMaker<S>;
    readonly end: make.IoMessageMaker<E>;
}
/**
 * Used in conditional types to check if a type (e.g. after omitting fields) is an empty object
 * This is needed because counter-intuitive neither `object` nor `{}` represent that.
 */
type EmptyObject = {
    [index: string | number | symbol]: never;
};
/**
 * Helper type to force a parameter to be not present of the computed type is an empty object
 */
type VoidWhenEmpty<T> = T extends EmptyObject ? void : T;
/**
 * Helper type to force a parameter to be an empty object if the computed type is an empty object
 * This is weird, but some computed types (e.g. using `Omit`) don't end up enforcing this.
 */
type ForceEmpty<T> = T extends EmptyObject ? EmptyObject : T;
/**
 * Make some properties optional
 */
type Optional<T, K extends keyof T> = Pick<Partial<T>, K> & Omit<T, K>;
/**
 * Ending the span returns the observed duration
 */
interface ElapsedTime {
    readonly asMs: number;
    readonly asSec: number;
}
/**
 * A message span that can be ended and read times from
 */
export interface IMessageSpan<E extends SpanEnd> extends IActionAwareIoHost {
    /**
     * An IoHelper wrapped around the span.
     */
    readonly asHelper: IoHelper;
    /**
     * An IoDefaultMessages wrapped around the span.
     */
    readonly defaults: IoDefaultMessages;
    /**
     * Get the time elapsed since the start
     */
    elapsedTime(): Promise<ElapsedTime>;
    /**
     * Sends a simple, generic message with the current timing
     * For more complex intermediate messages, get the `elapsedTime` and use `notify`
     */
    timing(maker: make.IoMessageMaker<Duration>, message?: string): Promise<ElapsedTime>;
    /**
     * End the span with a payload
     */
    end(payload: VoidWhenEmpty<Omit<E, keyof SpanEnd>>): Promise<ElapsedTime>;
    /**
     * End the span with a payload, overwriting
     */
    end(payload: VoidWhenEmpty<Optional<E, keyof SpanEnd>>): Promise<ElapsedTime>;
    /**
     * End the span with a message and payload
     */
    end(message: string, payload: ForceEmpty<Optional<E, keyof SpanEnd>>): Promise<ElapsedTime>;
}
/**
 * Helper class to make spans around blocks of work
 *
 * Blocks are enclosed by a start and end message.
 * All messages of the span share a unique id.
 * The end message contains the time passed between start and end.
 */
export declare class SpanMaker<S extends object, E extends SpanEnd> {
    private readonly definition;
    private readonly ioHelper;
    private makeHelper;
    constructor(ioHelper: IoHelper, definition: SpanDefinition<S, E>, makeHelper: (ioHost: IActionAwareIoHost) => IoHelper);
    /**
     * Starts the span and initially notifies the IoHost
     * @returns a message span
     */
    begin(payload: VoidWhenEmpty<S>): Promise<IMessageSpan<E>>;
    begin(message: string, payload: S): Promise<IMessageSpan<E>>;
}
export {};
